from distutils.core import setup

setup(
	name = 'dill_list',
	version = '1.1.0',
	py_modules = ['dill_list'],
	author = 'd1ll1nger',
	author_email = 'hfpython@headfirstlabs.com',
	url = 'http://www.headfirstlabs.com',
	description = 'A simple printer of nested lists',
)
